/*	Purpose: Split contiguous rom into two interleaved roms to burning
	Keywords: MT32, ROM
	Changelog:
	20160317 (sgeorge) - Initial release
*/

#define APP_RELEASE "20160317"

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <stdint.h>

int main(int argc, char *argv[])
{
	FILE *fp1, *fp2, *fp3;
	uint32_t len1, len2;
	uint32_t i;
	
	printf("MT32 ROM Joiner, v1.00 ("APP_RELEASE")- Stu George 2016\n");
	
	if(argc < 4)
	{
		printf("Syntx - %s input.rom outrom_A outrom_B\n", argv[0]);
		return 1;
	}
	
	fp1 = fopen(argv[1], "rb");
	if(fp1 == NULL)
	{
		printf("Unable to open first rom, %s\n", argv[1]);
		return 1;
	}
		
	fseek(fp1, 0x0L, SEEK_END);
	len1 = ftell(fp1);
	fseek(fp1, 0x0L, SEEK_SET);
	
	
	if(len1 != 0x10000)
	{
		fclose(fp1);
		printf("Input ROM (%s) is wrong size, Expected 0x10000, got 0x%05X\n", argv[1], len1);
		return 1;
	}
	
	fp2 = fopen(argv[2], "wb");
	if(fp2 == NULL)
	{
		fclose(fp1);
		printf("Unable to create output rom_A %s\n", argv[2]);
		return 1;
	}
	
	fp3 = fopen(argv[3], "wb");
	if(fp3 == NULL)
	{
		fclose(fp1);
		fclose(fp2);
		printf("Unable to create output rom_B %s\n", argv[3]);
		return 1;
	}
	
	
	for(i=0; i < 0x8000; i++)
	{
		uint8_t c;
	
		c = fgetc(fp1);
		fputc(c, fp2);
		
	 	c = fgetc(fp1);
		fputc(c, fp3);
	}
	
	fclose(fp1);
	fclose(fp2);
	fclose(fp3);
	
	return 0;
}


